@@ -203,7 +203,7 @@ class OptionLine(Line):
         return self.value
 
 
-class OscConfigParser(configparser.SafeConfigParser):
+class OscConfigParser(configparser.ConfigParser):
     """
     OscConfigParser() behaves like a normal ConfigParser() object. The
     only differences is that it preserves the order+format of configuration entries
@@ -212,7 +212,7 @@ class OscConfigParser(configparser.SafeConfigParser):
     class.
     """
     def __init__(self, defaults={}):
-        configparser.SafeConfigParser.__init__(self, defaults)
+        configparser.ConfigParser.__init__(self, defaults)
         self._sections = ConfigLineOrder()
 
     # XXX: unfortunately we have to override the _read() method from the ConfigParser()
@@ -321,7 +321,7 @@ class OscConfigParser(configparser.SafeConfigParser):
             fp.write(str(self))
             fp.write('\n')
         else:
-            configparser.SafeConfigParser.write(self, fp)
+            configparser.ConfigParser.write(self, fp)
 
     def has_option(self, section, option, proper=False, **kwargs):
         """
@@ -331,7 +331,7 @@ class OscConfigParser(configparser.SafeConfigParser):
         """
         if proper:
             return self.optionxform(option) in list(self._sections[section].keys())
-        return configparser.SafeConfigParser.has_option(self, section, option, **kwargs)
+        return configparser.ConfigParser.has_option(self, section, option, **kwargs)
 
     # XXX: simplify!
     def __str__(self):
