@@ -3,7 +3,7 @@
 # Author:  Trent Mick (TrentM@ActiveState.com)
 # Home:    http://trentm.com/projects/cmdln/
 
-from __future__ import print_function
+
 
 """An improvement on Python's standard cmd.py module.
 
@@ -45,23 +45,22 @@ import re
 import cmd
 import optparse
 import sys
-import time
 from pprint import pprint
-from datetime import datetime
+from datetime import date
 
 # this is python 2.x style
 def introspect_handler_2(handler):
     # Extract the introspection bits we need.
-    func = handler.im_func
-    if func.func_defaults:
-        func_defaults = func.func_defaults
+    func = handler.__func__
+    if func.__defaults__:
+        func_defaults = func.__defaults__
     else:
         func_defaults = []
     return \
         func_defaults,   \
-        func.func_code.co_argcount, \
-        func.func_code.co_varnames, \
-        func.func_code.co_flags,    \
+        func.__code__.co_argcount, \
+        func.__code__.co_varnames, \
+        func.__code__.co_flags,    \
         func
 
 def introspect_handler_3(handler):
@@ -86,7 +85,7 @@ else:
 
 #---- globals
 
-LOOP_ALWAYS, LOOP_NEVER, LOOP_IF_EMPTY = range(3)
+LOOP_ALWAYS, LOOP_NEVER, LOOP_IF_EMPTY = list(range(3))
 
 # An unspecified optional argument when None is a meaningful value.
 _NOT_SPECIFIED = ("Not", "Specified")
@@ -97,9 +96,6 @@ _NOT_SPECIFIED = ("Not", "Specified")
 _INCORRECT_NUM_ARGS_RE = re.compile(
     r"(takes [\w ]+ )(\d+)( arguments? \()(\d+)( given\))")
 
-_INCORRECT_NUM_ARGS_RE_PY3 = re.compile(
-    r"(missing\s+\d+.*)")
-
 # Static bits of man page
 MAN_HEADER = r""".TH %(ucname)s "1" "%(date)s" "%(name)s %(version)s" "User Commands"
 .SH NAME
@@ -326,8 +322,6 @@ class RawCmdln(cmd.Cmd):
         if self.optparser: # i.e. optparser=None means don't process for opts
             try:
                 self.options, args = self.optparser.parse_args(argv[1:])
-                # store args so we can use them in self.postoptparse()
-                self.args = args
             except CmdlnUserError as ex:
                 msg = "%s: %s\nTry '%s help' for info.\n"\
                       % (self.name, ex, self.name)
@@ -425,9 +419,9 @@ class RawCmdln(cmd.Cmd):
                         try:
                             try:
                                 #python 2.x
-                                line = raw_input(self._prompt_str)
-                            except NameError:
                                 line = input(self._prompt_str)
+                            except NameError:
+                                line = eval(input(self._prompt_str))
                         except EOFError:
                             line = 'EOF'
                     else:
@@ -625,17 +619,16 @@ class RawCmdln(cmd.Cmd):
         usage:
             ${name} man
         """
-        mandate = datetime.utcfromtimestamp(int(os.environ.get('SOURCE_DATE_EPOCH', time.time())))
-        self.stdout.write(
+        self.stdout.write(bytes(
             self.man_header % {
-                'date': mandate.strftime('%b %Y'),
+                'date': date.today().strftime('%b %Y'),
                 'version': self.get_version(),
                 'name': self.name,
                 'ucname': self.name.upper()
-                }
-            )
+                },
+            "utf-8"))
 
-        self.stdout.write(self.man_commands_header)
+        self.stdout.write(bytes(self.man_commands_header, "utf-8"))
         commands = self._help_get_command_list()
         for command, doc in commands:
             cmdname = command.split(' ')[0]
@@ -646,14 +639,14 @@ class RawCmdln(cmd.Cmd):
                     line = line[8:]
                 lines.append(man_escape(line))
 
-            self.stdout.write(
-                '.TP\n\\fB%s\\fR\n%s\n' % (command, '\n'.join(lines)))
+            self.stdout.write(bytes(
+                '.TP\n\\fB%s\\fR\n%s\n' % (command, '\n'.join(lines)), "utf-8"))
 
-        self.stdout.write(self.man_options_header)
-        self.stdout.write(
-            man_escape(self._help_preprocess('${option_list}', None)))
+        self.stdout.write(bytes(self.man_options_header, "utf-8"))
+        self.stdout.write(bytes(
+            man_escape(self._help_preprocess('${option_list}', None)), "utf-8"))
 
-        self.stdout.write(self.man_footer)
+        self.stdout.write(bytes(self.man_footer, "utf-8"))
 
         self.stdout.flush()
 
@@ -730,7 +723,7 @@ class RawCmdln(cmd.Cmd):
             "${cmd_option_list}": self._help_preprocess_cmd_option_list,
         }
 
-        for marker, preprocessor in preprocessors.items():
+        for marker, preprocessor in list(preprocessors.items()):
             if marker in help:
                 help = preprocessor(help, cmdname)
         return help
@@ -761,7 +754,7 @@ class RawCmdln(cmd.Cmd):
         # Find any aliases for commands.
         token2canonical = self._get_canonical_map()
         aliases = {}
-        for token, cmdname in token2canonical.items():
+        for token, cmdname in list(token2canonical.items()):
             if token == cmdname:
                 continue
             aliases.setdefault(cmdname, []).append(token)
@@ -793,10 +786,10 @@ class RawCmdln(cmd.Cmd):
             # practice dictates that command help strings begin with this, but
             # it isn't at all wanted for the command list.
             to_strip = "${cmd_name}:"
-            if doc and doc.lstrip().startswith(to_strip):
+            if doc and doc.startswith(to_strip):
                 #log.debug("stripping %r from start of %s's help string",
                 #          to_strip, cmdname)
-                doc = (doc.lstrip())[len(to_strip):].lstrip()
+                doc = doc[len(to_strip):].lstrip()
             if not getattr(self._get_cmd_handler(cmdname), "hidden", None):
                 linedata.append( (cmdstr, doc) )
 
@@ -898,7 +891,7 @@ class RawCmdln(cmd.Cmd):
                 warnings.warn("argument '**%s' on '%s.%s' command "
                               "handler will never get values"
                               % (name, self.__class__.__name__,
-                                 getattr(func, "__name__", getattr(func, "func_name"))))
+                                 getattr(func_defaults, "__name__", getattr(func_defaults, "func_name"))))
             if co_flags & CO_FLAGS_ARGS:
                 name = argnames.pop(-1)
                 tail = "[%s...]" % name.upper()
@@ -968,7 +961,7 @@ class RawCmdln(cmd.Cmd):
                     continue
                 cmd2funcname[cmdname] = attr
                 token2canonical[cmdname] = cmdname
-            for cmdname, funcname in cmd2funcname.items(): # add aliases
+            for cmdname, funcname in list(cmd2funcname.items()): # add aliases
                 func = getattr(self, funcname)
                 aliases = getattr(func, "aliases", [])
                 for alias in aliases:
@@ -1251,7 +1244,6 @@ class Cmdln(RawCmdln):
                     raise
                 msg = ex.args[0]
                 match = _INCORRECT_NUM_ARGS_RE.search(msg)
-                match_py3 = _INCORRECT_NUM_ARGS_RE_PY3.search(msg)
                 if match:
                     msg = list(match.groups())
                     msg[1] = int(msg[1]) - 3
@@ -1260,8 +1252,6 @@ class Cmdln(RawCmdln):
                     msg[3] = int(msg[3]) - 3
                     msg = ''.join(map(str, msg))
                     raise CmdlnUserError(msg)
-                elif match_py3:
-                    raise CmdlnUserError(match_py3.group(1))
                 else:
                     raise
         else:
