@@ -28,11 +28,6 @@ class ConfigMissingApiurl(ConfigError):
         ConfigError.__init__(self, msg, fname)
         self.url = url
 
-class ConfigMissingCredentialsError(ConfigError):
-    def __init__(self, msg, fname, url):
-        ConfigError.__init__(self, msg, fname)
-        self.url = url
-
 class APIError(OscBaseError):
     """Exception raised when there is an error in the output from the API"""
     def __init__(self, msg):
@@ -73,9 +68,6 @@ class WrongOptions(OscBaseError):
 class NoWorkingCopy(OscBaseError):
     """Exception raised when directory is neither a project dir nor a package dir"""
 
-class NotMissing(OscBaseError):
-    """Exception raised when link target should not exist, but it does"""
-
 class WorkingCopyWrongVersion(OscBaseError):
     """Exception raised when working copy's .osc/_osclib_version doesn't match"""
 
@@ -87,7 +79,7 @@ class WorkingCopyOutdated(OscBaseError):
     def __str__(self):
         return ('Working copy \'%s\' is out of date (rev %s vs rev %s).\n'
                'Looks as if you need to update it first.' \
-                    % (self.args[0], self.args[1], self.args[2]))
+                    % (self[0], self[1], self[2]))
 
 class PackageError(OscBaseError):
     """Base class for all Package related exceptions"""
@@ -120,10 +112,10 @@ class PackageNotInstalled(OscBaseError):
     Exception raised when a package is not installed on local system
     """
     def __init__(self, pkg):
-        OscBaseError.__init__(self, (pkg,))
+        OscBaseError.__init__(self, pkg)
 
     def __str__(self):
-        return 'Package %s is required for this operation' % self.args
+        return 'Package %s is required for this operation' % ''.join(self.args)
 
 class SignalInterrupt(Exception):
     """Exception raised on SIGTERM and SIGHUP."""
@@ -155,7 +147,7 @@ class PackageFileConflict(PackageError):
         self.msg = msg
 
 class PackageInternalError(PackageError):
-    def __init__(self, prj, pac, msg):
+    def __init__(self, prj, pac=None, msg=None):
         PackageError.__init__(self, prj, pac)
         self.msg = msg
 # vim: sw=4 et
