@@ -3,24 +3,24 @@
 # and distributed under the terms of the GNU General Public Licence,
 # either version 2, or (at your option) any later version.
 
-from __future__ import print_function
 
+
+import M2Crypto.httpslib
 from M2Crypto.SSL.Checker import SSLVerificationError
-from M2Crypto import m2, SSL, httpslib
+from M2Crypto import m2, SSL
 import M2Crypto.m2urllib2
 import socket
 import sys
-import inspect
 
 try:
-    from urllib.parse import urlparse, splithost, splitport, splittype, urldefrag
+    from urllib.parse import urlparse, splithost, splitport, splittype
     from urllib.request import addinfourl
     from http.client import HTTPSConnection
 except ImportError:
     #python 2.x
-    from urlparse import urlparse, urldefrag
-    from urllib import addinfourl, splithost, splitport, splittype
-    from httplib import HTTPSConnection
+    from urllib.parse import urlparse
+    from urllib.parse import splithost, splitport, splittype
+    from http.client import HTTPSConnection
 
 from .core import raw_input
 
@@ -117,7 +117,7 @@ class ValidationErrors:
         self.failures[depth].errs.append(err)
 
     def show(self, out):
-        for depth in self.failures.keys():
+        for depth in list(self.failures.keys()):
             cert = self.failures[depth].cert
             print("*** certificate verify failed at depth %d" % depth, file=out)
             print("Subject: ", cert.get_subject(), file=out)
@@ -173,6 +173,7 @@ class mySSLContext(SSL.Context):
 
 class myHTTPSHandler(M2Crypto.m2urllib2.HTTPSHandler):
     handler_order = 499
+    saved_session = None
 
     def __init__(self, *args, **kwargs):
         self.appname = kwargs.pop('appname', 'generic')
@@ -184,30 +185,26 @@ class myHTTPSHandler(M2Crypto.m2urllib2.HTTPSHandler):
     # "do_open()" and "https_open()" so that we just need to override
     # the small "https_open()" method...)
     def https_open(self, req):
-        # https://docs.python.org/3.3/library/urllib.request.html#urllib.request.Request.get_host
-        try:     # up to python-3.2
-            host = req.get_host()
-        except AttributeError:  # from python-3.3
-            host = req.host
+        host = req.get_host()
         if not host:
-            raise M2Crypto.m2urllib2.URLError('no host given')
+            raise M2Crypto.m2urllib2.URLError('no host given: ' + req.get_full_url())
 
         # Our change: Check to see if we're using a proxy.
         # Then create an appropriate ssl-aware connection.
         full_url = req.get_full_url()
         target_host = urlparse(full_url)[1]
 
-        if target_host != host:
-            request_uri = urldefrag(full_url)[0]
-            h = myProxyHTTPSConnection(host=host, appname=self.appname, ssl_context=self.ctx)
+        if (target_host != host):
+            h = myProxyHTTPSConnection(host = host, appname = self.appname, ssl_context = self.ctx)
+            # M2Crypto.ProxyHTTPSConnection.putrequest expects a fullurl
+            selector = full_url
         else:
-            try:     # up to python-3.2
-                request_uri = req.get_selector()
-            except AttributeError:  # from python-3.3
-                request_uri = req.selector
-            h = myHTTPSConnection(host=host, appname=self.appname, ssl_context=self.ctx)
+            h = myHTTPSConnection(host = host, appname = self.appname, ssl_context = self.ctx)
+            selector = req.get_selector()
         # End our change
         h.set_debuglevel(self._debuglevel)
+        if self.saved_session:
+            h.set_session(self.saved_session)
 
         headers = dict(req.headers)
         headers.update(req.unredirected_hdrs)
@@ -219,9 +216,13 @@ class myHTTPSHandler(M2Crypto.m2urllib2.HTTPSHandler):
         # request.
         headers["Connection"] = "close"
         try:
-            h.request(req.get_method(), request_uri, req.data, headers)
+            h.request(req.get_method(), selector, req.data, headers)
+            s = h.get_session()
+            if s:
+                self.saved_session = s
             r = h.getresponse()
-        except socket.error as err:  # XXX what error?
+        except socket.error as err: # XXX what error?
+            err.filename = full_url
             raise M2Crypto.m2urllib2.URLError(err)
 
         # Pick apart the HTTPResponse object to get the addinfourl
@@ -231,73 +232,25 @@ class myHTTPSHandler(M2Crypto.m2urllib2.HTTPSHandler):
         # for Windows.  That adapter calls recv(), so delegate recv()
         # to read().  This weird wrapping allows the returned object to
         # have readline() and readlines() methods.
+
+        # XXX It might be better to extract the read buffering code
+        # out of socket._fileobject() and into a base class.
+
         r.recv = r.read
-        if (sys.version_info < (3, 0)):
-            fp = socket._fileobject(r, close=True)
-        else:
-            r._decref_socketios = lambda: None
-            r.ssl = h.sock.ssl
-            r._timeout = -1.0
-            # hack to bypass python3 bug with 0 buffer size and
-            # http/client.py readinto method for response class
-            if r.length is not None and r.length == 0:
-                r.readinto = lambda b: 0
-            r.recv_into = r.readinto
-            fp = socket.SocketIO(r, 'rb')
+        fp = socket._fileobject(r)
 
         resp = addinfourl(fp, r.msg, req.get_full_url())
         resp.code = r.status
         resp.msg = r.reason
         return resp
 
-
 class myHTTPSConnection(M2Crypto.httpslib.HTTPSConnection):
     def __init__(self, *args, **kwargs):
         self.appname = kwargs.pop('appname', 'generic')
         M2Crypto.httpslib.HTTPSConnection.__init__(self, *args, **kwargs)
 
-    def _connect(self, family):
-        # workaround for old M2Crypto versions where the the
-        # SSL.Connection.__init__ constructor has no "family" parameter
-        kwargs = {}
-        argspec = inspect.getargspec(SSL.Connection.__init__)
-        if 'family' in argspec.args:
-            kwargs['family'] = family
-        elif family != socket.AF_INET:
-            # old SSL.Connection classes implicitly use socket.AF_INET
-            return False
-
-        self.sock = SSL.Connection(self.ssl_ctx, **kwargs)
-        if self.session:
-            self.sock.set_session(self.session)
-        if hasattr(self.sock, 'set_tlsext_host_name'):
-            self.sock.set_tlsext_host_name(self.host)
-        self.sock.connect((self.host, self.port))
-        return True
-
-    def connect(self):
-        # based on M2Crypto.httpslib.HTTPSConnection.connect
-        last_exc = None
-        connected = False
-        for addrinfo in socket.getaddrinfo(self.host, self.port,
-                                           socket.AF_UNSPEC,
-                                           socket.SOCK_STREAM,
-                                           0, 0):
-            try:
-                connected = self._connect(addrinfo[0])
-                if connected:
-                    break
-            except socket.error as e:
-                last_exc = e
-            finally:
-                if not connected and self.sock is not None:
-                    self.sock.close()
-        if not connected:
-            if last_exc is None:
-                msg = 'getaddrinfo returned empty list or unsupported families'
-                raise RuntimeError(msg)
-            raise last_exc
-        # ok we are connected, verify cert
+    def connect(self, *args):
+        M2Crypto.httpslib.HTTPSConnection.connect(self, *args)
         verify_certificate(self)
 
     def getHost(self):
@@ -398,7 +351,7 @@ Would you like to
 """, file=out)
 
             print("Enter choice [0129]: ", end='', file=out)
-            r = raw_input()
+            r = input()
             if not r or r == '0':
                 connection.close()
                 raise SSLVerificationError("Untrusted Certificate")
