@@ -13,7 +13,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
-from __future__ import print_function
+
 
 import os
 import re
@@ -23,7 +23,7 @@ import stat
 #XXX: python 2.7 contains io.StringIO, which needs unicode instead of str
 #therefor try to import old stuff before new one here
 try:
-    from StringIO import StringIO
+    from io import StringIO
 except ImportError:
     from io import StringIO
 
