@@ -127,8 +127,8 @@ class ArchQuery(packagequery.PackageQuery, packagequery.PackageQueryResult):
             if not (len(ver1) and len(ver2)):
                 break
             # check if we have a digits segment
-            mo1 = re.match('(\d+)', ver1)
-            mo2 = re.match('(\d+)', ver2)
+            mo1 = re.match(r'(\d+)', ver1)
+            mo2 = re.match(r'(\d+)', ver2)
             numeric = True
             if mo1 is None:
                 mo1 = re.match('([a-zA-Z]+)', ver1)
