@@ -48,9 +48,9 @@ class DebQuery(packagequery.PackageQuery, packagequery.PackageQueryResult):
     def __parse_control(self, control, all_tags=False, self_provides=True, *extra_tags):
         data = control.readline().strip()
         while data:
-            field, val = re.split(':\s*', data.strip(), 1)
+            field, val = re.split(r':\s*', data.strip(), 1)
             data = control.readline()
-            while data and re.match('\s+', data):
+            while data and re.match(r'\s+', data):
                 val += '\n' + data.strip()
                 data = control.readline().rstrip()
             field = field.replace('-', '_').lower()
@@ -69,11 +69,11 @@ class DebQuery(packagequery.PackageQuery, packagequery.PackageQueryResult):
             self.fields['version'] = verep[1]
         else:
             self.fields['epoch'] = '0'
-        self.fields['provides'] = [ i.strip() for i in re.split(',\s*', self.fields.get('provides', '')) if i ]
-        self.fields['depends'] = [ i.strip() for i in re.split(',\s*', self.fields.get('depends', '')) if i ]
-        self.fields['pre_depends'] = [ i.strip() for i in re.split(',\s*', self.fields.get('pre_depends', '')) if i ]
-        self.fields['conflicts'] = [ i.strip() for i in re.split(',\s*', self.fields.get('conflicts', '')) if i ]
-        self.fields['breaks'] = [ i.strip() for i in re.split(',\s*', self.fields.get('breaks', '')) if i ]
+        self.fields['provides'] = [ i.strip() for i in re.split(r',\s*', self.fields.get('provides', '')) if i ]
+        self.fields['depends'] = [ i.strip() for i in re.split(r',\s*', self.fields.get('depends', '')) if i ]
+        self.fields['pre_depends'] = [ i.strip() for i in re.split(r',\s*', self.fields.get('pre_depends', '')) if i ]
+        self.fields['conflicts'] = [ i.strip() for i in re.split(r',\s*', self.fields.get('conflicts', '')) if i ]
+        self.fields['breaks'] = [ i.strip() for i in re.split(r',\s*', self.fields.get('breaks', '')) if i ]
         if self_provides:
             # add self provides entry
             self.fields['provides'].append('%s (= %s)' % (self.name(), '-'.join(versrel)))
@@ -142,8 +142,8 @@ class DebQuery(packagequery.PackageQuery, packagequery.PackageQueryResult):
         """
         # 32 is arbitrary - it is needed for the "longer digit string wins" handling
         # (found this nice approach in Build/Deb.pm (build package))
-        ver1 = re.sub('(\d+)', lambda m: (32 * '0' + m.group(1))[-32:], ver1)
-        ver2 = re.sub('(\d+)', lambda m: (32 * '0' + m.group(1))[-32:], ver2)
+        ver1 = re.sub(r'(\d+)', lambda m: (32 * '0' + m.group(1))[-32:], ver1)
+        ver2 = re.sub(r'(\d+)', lambda m: (32 * '0' + m.group(1))[-32:], ver2)
         vers = list(map(lambda x, y: (x or '', y or ''), ver1, ver2))
         for v1, v2 in vers:
             if v1 == v2:
