@@ -1,6 +1,5 @@
 
-from __future__ import print_function
-from osc.util.helper import decode_it
+
 
 class PackageError(Exception):
     """base class for all package related errors"""
@@ -15,8 +14,8 @@ class PackageQueries(dict):
     wanted architecture and if it has a greater version than the current value.
     """
 
-    # map debian and rpm arches to common obs arches
-    architectureMap = {'i386': ['i586', 'i686'], 'amd64': ['x86_64'], 'ppc64el': ['ppc64le'], 'armv6hl': ['armv6l'], 'armv7hl': ['armv7l']}
+    # map debian arches to common obs arches
+    architectureMap = {'i386': ['i586', 'i686'], 'amd64': ['x86_64'], 'ppc64el': ['ppc64le']}
 
     def __init__(self, wanted_architecture):
         self.wanted_architecture = wanted_architecture
@@ -26,16 +25,16 @@ class PackageQueries(dict):
         """Adds package query to dict if it is of the correct architecture and
         is newer (has a greater version) than the currently assigned package.
 
-        :param query: a PackageQuery
+        @param a PackageQuery
         """
         self.__setitem__(query.name(), query)
 
     def __setitem__(self, name, query):
-        if decode_it(name) != decode_it(query.name()):
+        if name != query.name():
             raise ValueError("key '%s' does not match "
                              "package query name '%s'" % (name, query.name()))
 
-        architecture = decode_it(query.arch())
+        architecture = query.arch()
 
         if (architecture in [self.wanted_architecture, 'noarch', 'all', 'any']
             or self.wanted_architecture in self.architectureMap.get(architecture,
@@ -61,19 +60,18 @@ class PackageQuery:
         f.seek(0)
         extra_tags = ()
         pkgquery = None
-        if magic[:4] == b'\xed\xab\xee\xdb':
+        if magic[:4] == '\xed\xab\xee\xdb':
             from . import rpmquery
             pkgquery = rpmquery.RpmQuery(f)
             extra_tags = extra_rpmtags
-        elif magic == b'!<arch>':
+        elif magic == '!<arch>':
             from . import debquery
             pkgquery = debquery.DebQuery(f)
             extra_tags = extra_debtags
-        elif magic[:5] == b'<?xml':
+        elif magic[:5] == '<?xml':
             f.close()
             return None
-        # arch tar ball compressed with gz, xz or zst
-        elif magic[:5] == b'\375\067zXZ' or magic[:2] == b'\037\213' or magic[:4] == b'(\xb5/\xfd':
+        elif magic[:5] == '\375\067zXZ' or magic[:2] == '\037\213':
             from . import archquery
             pkgquery = archquery.ArchQuery(f)
         else:
@@ -87,7 +85,7 @@ class PackageQuery:
         f = open(filename, 'rb')
         magic = f.read(7)
         f.seek(0)
-        if magic[:4] == b'\xed\xab\xee\xdb':
+        if magic[:4] == '\xed\xab\xee\xdb':
             from . import rpmquery
             f.close()
             return rpmquery.RpmQuery.queryhdrmd5(filename)
@@ -129,18 +127,6 @@ class PackageQueryResult:
     def obsoletes(self):
         raise NotImplementedError
 
-    def recommends(self):
-        raise NotImplementedError
-
-    def suggests(self):
-        raise NotImplementedError
-
-    def supplements(self):
-        raise NotImplementedError
-
-    def enhances(self):
-        raise NotImplementedError
-
     def gettag(self, tag):
         raise NotImplementedError
 
@@ -151,20 +137,11 @@ class PackageQueryResult:
         raise NotImplementedError
 
     def evr(self):
-        evr = self.version()
-
-        if self.release():
-            evr += b"-" + self.release()
-
+        evr = self.version() + "-" + self.release()
         epoch = self.epoch()
         if epoch is not None and epoch != 0:
-            evr = epoch + b":" + evr
-        return evr
-
-
-def cmp(a, b):
-    return (a > b) - (a < b)
-
+            evr = epoch + ":" + evr 
+        return evr 
 
 if __name__ == '__main__':
     import sys
