@@ -17,7 +17,7 @@ if __name__ == '__main__':
         prof = hotshot.Profile(filename)
 
         prof.runcall(commandline.main)
-        print 'run complete. analyzing.'
+        print('run complete. analyzing.')
         prof.close()
 
         stats = hotshot.stats.load(filename)
