@@ -3,8 +3,8 @@ from common import OscTestCase
 
 import os
 
-FIXTURES_DIR = os.path.join(os.getcwd(), 'conf_fixtures')
-
+#FIXTURES_DIR = os.path.join(os.getcwd(), 'conf_fixtures')
+FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'conf_fixtures')
 def suite():
     import unittest
     return unittest.makeSuite(TestConf)
