@@ -1,10 +1,10 @@
 import osc.core
 import osc.oscerr
 import os
-from .common import OscTestCase
-
-FIXTURES_DIR = os.path.join(os.path.dirname(__file__), 'project_package_status_fixtures')
+from common import OscTestCase
 
+#FIXTURES_DIR = os.path.join(os.getcwd(), 'project_package_status_fixtures')
+FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'project_package_status_fixtures')
 def suite():
     import unittest
     return unittest.makeSuite(TestPackageStatus)
