@@ -2,15 +2,10 @@ import osc.core
 import osc.oscerr
 import os
 import sys
-from .common import GET, PUT, POST, DELETE, OscTestCase
-try:
-    # Works up to Python 3.8, needed for Python < 3.3 (inc 2.7)
-    from xml.etree import cElementTree as ET
-except ImportError:
-    # will import a fast implementation from 3.3 onwards, needed
-    # for 3.9+
-    from xml.etree import ElementTree as ET
-FIXTURES_DIR = os.path.join(os.path.dirname(__file__), 'repairwc_fixtures')
+from common import GET, PUT, POST, DELETE, OscTestCase
+from xml.etree import cElementTree as ET
+#FIXTURES_DIR = os.path.join(os.getcwd(), 'repairwc_fixtures')
+FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'repairwc_fixtures')
 
 def suite():
     import unittest
@@ -211,7 +206,7 @@ class TestRepairWC(OscTestCase):
         try:
             from urllib.error import URLError
         except ImportError:
-            from urllib2 import URLError
+            from urllib.error import URLError
         self._change_to_pkg('invalid_apiurl')
         p = osc.core.Package('.', wc_check=False)
         self.assertRaises(URLError, p.wc_repair, 'http:/localhost')
@@ -257,7 +252,7 @@ class TestRepairWC(OscTestCase):
         try:
             from urllib.error import URLError
         except ImportError:
-            from urllib2 import URLError
+            from urllib.error import URLError
         prj_dir = os.path.join(self.tmpdir, 'prj_invalidapiurl')
         shutil.copytree(os.path.join(self._get_fixtures_dir(), 'prj_invalidapiurl'), prj_dir)
         storedir = os.path.join(prj_dir, osc.core.store)
