@@ -3,7 +3,8 @@ import osc.oscerr
 import os
 from common import OscTestCase
 
-FIXTURES_DIR = os.path.join(os.getcwd(), 'request_fixtures')
+#FIXTURES_DIR = os.path.join(os.getcwd(), 'request_fixtures')
+FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'request_fixtures')
 
 def suite():
     import unittest
@@ -341,7 +342,6 @@ class TestRequest(OscTestCase):
         self.assertEqual(r.state.name, 'accepted')
         self.assertEqual(r.state.when, '2010-12-27T01:36:29')
         self.assertEqual(r.state.who, 'user1')
-        self.assertEqual(r.state.approver, None)
         self.assertEqual(r.state.comment, '')
         self.assertEqual(r.statehistory[0].when, '2010-12-13T13:02:03')
         self.assertEqual(r.statehistory[0].who, 'creator')
@@ -374,7 +374,6 @@ class TestRequest(OscTestCase):
         self.assertTrue(r.actions[1].tgt_package is None)
         self.assertEqual(r.state.name, 'review')
         self.assertEqual(r.state.when, '2010-12-27T01:36:29')
-        self.assertEqual(r.state.approver, 'someone')
         self.assertEqual(r.state.who, 'abc')
         self.assertEqual(r.state.comment, '')
         self.assertEqual(r.reviews[0].state, 'new')
@@ -386,7 +385,7 @@ class TestRequest(OscTestCase):
         self.assertEqual(r.statehistory[0].when, '2010-12-11T00:00:00')
         self.assertEqual(r.statehistory[0].who, 'creator')
         self.assertEqual(r.statehistory[0].comment, '')
-        self.assertEqual(r.creator, 'creator')
+        self.assertEqual(r.get_creator(), 'creator')
         self.assertTrue(len(r.statehistory) == 1)
         self.assertTrue(len(r.reviews) == 1)
         self.assertEqual(xml, r.to_str())
@@ -394,7 +393,7 @@ class TestRequest(OscTestCase):
     def test_read_request3(self):
         """read in a request (with an "empty" comment+description)"""
         from xml.etree import cElementTree as ET
-        xml = """<request creator="xyz" id="2">
+        xml = """<request id="2">
   <action type="set_bugowner">
     <target project="foo" />
     <person name="buguser" />
@@ -417,8 +416,8 @@ class TestRequest(OscTestCase):
         self.assertEqual(r.description, '')
         self.assertTrue(len(r.statehistory) == 0)
         self.assertTrue(len(r.reviews) == 0)
-        self.assertEqual(r.creator, 'xyz')
-        exp = """<request creator="xyz" id="2">
+        self.assertEqual(r.get_creator(), 'xyz')
+        exp = """<request id="2">
   <action type="set_bugowner">
     <target project="foo" />
     <person name="buguser" />
@@ -468,7 +467,7 @@ class TestRequest(OscTestCase):
         r = osc.core.Request()
         r = osc.core.Request()
         r.read(ET.fromstring(xml))
-        self.assertEqual(r.creator, 'creator')
+        self.assertEqual(r.get_creator(), 'creator')
         exp = """\
 Request: #123
 
@@ -485,10 +484,8 @@ test.
 State:   review     2010-12-27T01:36:29 abc
 Comment: currently in review
 
-Review:  accepted   Group: group1                                      2010-12-29T00:11:22 abc                   
-  accepted
-         new        Group: group1                                      2010-12-28T00:11:22 abc                   
-  review start
+Review:  accepted   Group: group1                                      2010-12-29T00:11:22 abc                   accepted
+         new        Group: group1                                      2010-12-28T00:11:22 abc                   review start
 
 History: 2010-12-12T00:00:00 creator      revoked
          2010-12-11T00:00:00 creator      new"""
@@ -498,7 +495,7 @@ History: 2010-12-12T00:00:00 creator      revoked
         """test the __str__ method"""
         from xml.etree import cElementTree as ET
         xml = """\
-<request creator="creator" id="98765">
+<request id="98765">
   <action type="change_devel">
     <source project="devprj" package="devpkg" />
     <target project="foo" package="bar" />
@@ -510,7 +507,7 @@ History: 2010-12-12T00:00:00 creator      revoked
 </request>"""
         r = osc.core.Request()
         r.read(ET.fromstring(xml))
-        self.assertEqual(r.creator, 'creator')
+        self.assertEqual(r.get_creator(), 'creator')
         exp = """\
 Request: #98765
 
@@ -529,7 +526,7 @@ Comment: <no comment>"""
         """load old-style submitrequest"""
         from xml.etree import cElementTree as ET
         xml = """\
-<request creator="olduser" id="1234" type="submit">
+<request id="1234" type="submit">
   <submit>
     <source package="baz" project="foobar" />
     <target package="baz" project="foo" />
@@ -550,9 +547,9 @@ Comment: <no comment>"""
         self.assertEqual(r.state.when, '2010-12-30T02:11:22')
         self.assertEqual(r.state.who, 'olduser')
         self.assertEqual(r.state.comment, '')
-        self.assertEqual(r.creator, 'olduser')
+        self.assertEqual(r.get_creator(), 'olduser')
         exp = """\
-<request creator="olduser" id="1234">
+<request id="1234">
   <action type="submit">
     <source package="baz" project="foobar" />
     <target package="baz" project="foo" />
